import importlib.util
from typing import List


def check_dependency(module: str) -> bool:
    """Check if the provided module name can be imported.

    :param module: Module name
    :return: True if the module was found, False otherwise
    """
    try:
        return importlib.util.find_spec(module) is not None
    except ImportError:
        return False


def filter_missing(modules: List[str]) -> List[str]:
    """Check that provided modules exist. Return the ones that are not installed.

    :param modules: List of required modules
    :return: List of missing modules
    """
    return [mod for mod in modules if not check_dependency(mod)]


def print_missing_dependency_info(should_install: List[str]):
    """Print instructions for missing dependencies.

    :param should_install: List of modules that should be installed
    """
    print(
        f"The command you have chosen requires the {', '.join(should_install)!r}"
        "package(s) to be installed."
    )
    print("To install them, run the following command\n\n")
    print(f"\t\tpip3 install {' '.join(should_install)}\n\n")
